﻿import mvcclock.*

/**
 * An example model-view-controller (MVC) clock application.
 */
class mvcclock.Clock {
  // The clock data (i.e., the Model).
  private var clock_model:ClockModel;

  // Two different displays of the clock's data (i.e., the Views).
  private var clock_analogview:ClockAnalogView;
  private var clock_digitalview:ClockDigitalView;

  // A toolbar for controlling the clock.
  private var clock_tools:ClockTools;

  /**
   * Clock Constructor
   *
   * @param   target   The movie clip to which the digital and 
   *                   analog views will be attached.
   * @param   h   The initial hour at which to set the clock.
   * @param   m   The initial minute at which to set the clock.
   * @param   s   The initial second at which to set the clock.
   */
  public function Clock (target:MovieClip, h:Number, m:Number, s:Number) {
    // Create the data model.
    clock_model = new ClockModel();

    // Create the digital clock view.
    clock_digitalview = new ClockDigitalView(clock_model, undefined,
                                             24, ":", target, 0, 253, 265);
    clock_model.addObserver(clock_digitalview);

    // Create the analog clock view.
    clock_analogview = new ClockAnalogView(clock_model, undefined, 
                                           target, 1, 275, 200);
    clock_model.addObserver(clock_analogview);

    // Create the clock tools view.
    clock_tools = new ClockTools(clock_model, undefined, target, 2, 120, 300);
    clock_model.addObserver(clock_tools);

    // Set the time.
    clock_model.setTime(h, m, s);

    // Start the clock ticking.
    clock_model.start();
  }

  /**
   * System entry point. Starts the clock application running.
   */
  public static function main (target:MovieClip, h:Number, m:Number, s:Number) {
    var clock:Clock = new Clock(target, h, m, s);
  }
}